@@ -110,12 +110,12 @@ class Mail_Queue
             $headers['To'] = Mail_API::fixAddressQuoting($headers['To']);
         }
 
-        $prepared_headers = Mail_API::prepareHeaders($headers);
-        if (PEAR::isError($prepared_headers)) {
-            print_r(debug_backtrace());
-            return;
+        $res = Mail_API::prepareHeaders($headers);
+        if (PEAR::isError($res)) {
+            Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
+            return $res;
         }
-        list(,$text_headers) = $prepared_headers;
+        list(,$text_headers) = $res;
 
         $stmt = "INSERT INTO
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "mail_queue
@@ -236,11 +236,9 @@ class Mail_Queue
         $res = $mail->send($recipient, $headers, $body);
         if (PEAR::isError($res)) {
             // special handling of errors when the mail server is down
-            if (($status == 'error') || (strstr($res->getMessage(), 'unable to connect to smtp server')) || (stristr($res->getMessage(), 'Failed to connect to') !== false)) {
-                Error_Handler::logToFile(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
-            } else {
-                Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
-            }
+            $msg = $res->getMessage();
+            $cant_notify = (($status == 'error') || (strstr($msg , 'unable to connect to smtp server')) || (stristr($msg, 'Failed to connect to') !== false));
+            Error_Handler::logError(array($msg, $res->getDebugInfo()), __FILE__, __LINE__, !$cant_notify);
             return $res;
         } else {
             return true;
@@ -427,14 +425,18 @@ class Mail_Queue
     }
 
 
-    function getMessageRecipients($type, $type_id)
+    function getMessageRecipients($types, $type_id)
     {
+        if (!is_array($types)) {
+            $types = array($types);
+        }
+        $types = Misc::escapeString($types);
         $sql = "SELECT
                     maq_recipient
                 FROM
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "mail_queue
                 WHERE
-                    maq_type = '" . Misc::escapeString($type) . "' AND
+                    maq_type IN('" . join("', '", $types) . "') AND
                     maq_type_id = " . Misc::escapeInteger($type_id);
         $res = $GLOBALS["db_api"]->dbh->getCol($sql);
         if (PEAR::isError($res)) {
