@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,12 +22,12 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
 
-include_once(APP_INC_PATH . "class.error_handler.php");
-include_once(APP_INC_PATH . "class.setup.php");
+require_once(APP_INC_PATH . "class.error_handler.php");
+require_once(APP_INC_PATH . "class.setup.php");
 
 /**
  * Class to hold methods and algorythms that woudln't fit in other classes, such
@@ -35,7 +35,7 @@ include_once(APP_INC_PATH . "class.setup.php");
  * PHP configurations.
  *
  * @version 1.0
- * @author Joo Prado Maia <jpm@mysql.com>
+ * @author João Prado Maia <jpm@mysql.com>
  */
 
 class Misc
@@ -472,13 +472,9 @@ class Misc
         if ((!empty($minutes)) && ($minutes < 6)) {
             $return = sprintf("%02dm", $minutes);
         } elseif ($hours > 24 && $omit_days == false) {
-            $mins = ($minutes % 60) / 60;
-            $days = $hours / 24;
-            $hours = $hours % 24;
-            $hours += $mins;
-            $return = sprintf("%02dd %.1fh", $days, $hours);
+            $return = sprintf("%dd %dh %dm (%dh %dm)", floor($minutes/24/60), floor($minutes/60)%24, $minutes%60, floor($minutes/60), $minutes%60);
         } else {
-            $return = round($hours,1) . 'h';
+            $return = sprintf("%dh %dm", floor($minutes/60), $minutes%60);
         }
         if ($omit_empty) {
             $chunks = explode(" ", $return);
@@ -580,7 +576,7 @@ class Misc
         if (!is_writable($file)) {
             if (!stristr(PHP_OS, "win")) {
                 // let's try to change the permissions ourselves
-                @chmod($file, 0777);
+                @chmod($file, 0755);
                 clearstatcache();
                 if (!is_writable($file)) {
                     return false;
@@ -617,7 +613,7 @@ class Misc
      */
     function highlightQuotedReply($text)
     {
-        include_once(APP_SMARTY_PATH . "plugins/modifier.highlight_quoted.php");
+        require_once(APP_SMARTY_PATH . "plugins/modifier.highlight_quoted.php");
         return smarty_modifier_highlight_quoted($text);
     }
 
@@ -699,10 +695,26 @@ class Misc
         }
         return $values;
     }
+
+
+    /**
+     * Changes a boolean value to either "Yes" or "No".
+     *
+     * @access  public
+     * @param   boolean $value The boolean value
+     * @return  string Either 'Yes' or 'No'.
+     */
+    function getBooleanDisplayValue($value)
+    {
+        if ($value == true) {
+            return ev_gettext('Yes');
+        } else {
+            return ev_gettext('No');
+        }
+    }
 }
 
 // benchmarking the included file (aka setup time)
 if (APP_BENCHMARK) {
     $GLOBALS['bench']->setMarker('Included Misc Class');
 }
-?>
