@@ -252,6 +252,8 @@ class Notification
      */
     function notifyNewEmail($usr_id, $issue_id, $message, $internal_only = FALSE, $assignee_only = FALSE, $type = '', $sup_id = false)
     {
+        $prj_id = Issue::getProjectID($issue_id);
+
         $full_message = $message['full_email'];
         $sender = $message['from'];
         $sender_email = strtolower(Mail_API::getEmailAddress($sender));
@@ -266,8 +268,9 @@ class Notification
         $subscribed_emails = Notification::getSubscribedEmails($issue_id, 'emails');
         $subscribed_emails = array_map('strtolower', $subscribed_emails);
         if ((!Notification::isIssueRoutingSender($issue_id, $sender)) &&
-        (!Notification::isBounceMessage($sender_email)) &&
-        (!in_array($sender_email, $subscribed_emails))) {
+                (!Notification::isBounceMessage($sender_email)) &&
+                (!in_array($sender_email, $subscribed_emails)) &&
+                (Workflow::shouldAutoAddToNotificationList($prj_id))) {
             $actions = array('emails');
             Notification::subscribeEmail($usr_id, $issue_id, $sender_email, $actions);
         }
@@ -353,7 +356,7 @@ class Notification
             $recipient_usr_id = User::getUserIDByEmail(Mail_API::getEmailAddress($to));
             $to = MIME_Helper::encodeAddress($to);
             // add the warning message about replies being blocked or not
-            $fixed_body = Mail_API::addWarningMessage($issue_id, $to, $body);
+            $fixed_body = Mail_API::addWarningMessage($issue_id, $to, $body, $headers);
             $headers['To'] = $to;
             $mime = new Mail_mime("\r\n");
             $hdrs = $mime->headers($headers);
@@ -375,6 +378,7 @@ class Notification
         $stmt = "SELECT
                     iss_id,
                     iss_customer_id,
+                    iss_customer_contract_id,
                     iss_summary,
                     iss_description,
                     iss_duplicated_iss_id,
@@ -421,7 +425,7 @@ class Notification
             $res['assigned_users'] = implode(", ", Issue::getAssignedUsers($issue_id));
             // get customer information, if any
             if ((!empty($res['iss_customer_id'])) && (Customer::hasCustomerIntegration($res['prj_id']))) {
-                $res['customer_info'] = Customer::getDetails($res['prj_id'], $res['iss_customer_id']);
+                $res['customer_info'] = Customer::getDetails($res['prj_id'], $res['iss_customer_id'], false, $res['iss_customer_contract_id']);
             }
             return $res;
         }
@@ -609,6 +613,7 @@ class Notification
      */
     function notifyIssueUpdated($issue_id, $old, $new)
     {
+        $prj_id = Issue::getProjectID($issue_id);
         $diffs = array();
         if (@$new["keep_assignments"] == "no") {
             if (empty($new['assignments'])) {
@@ -654,9 +659,9 @@ class Notification
         }
         if ($old["iss_description"] != $new["description"]) {
             // need real diff engine here
-            require_once 'Text_Diff/Diff.php';
-            require_once 'Text_Diff/Diff/Renderer.php';
-            require_once 'Text_Diff/Diff/Renderer/unified.php';
+            require_once 'Text/Diff.php';
+            require_once 'Text/Diff/Renderer.php';
+            require_once 'Text/Diff/Renderer/unified.php';
             $old['iss_description'] = explode("\n", $old['iss_description']);
             $new['description'] = explode("\n", $new['description']);
             $diff = &new Text_Diff($old["iss_description"], $new["description"]);
@@ -687,6 +692,9 @@ class Notification
                 $emails[] = $email;
             }
         }
+        // get additional email addresses to notify
+        $emails = array_merge($emails, Workflow::getAdditionalEmailAddresses($prj_id, $issue_id, 'issue_updated', array('old' => $old, 'new' => $new)));
+
         $data = Notification::getIssueDetails($issue_id);
         $data['diffs'] = implode("\n", $diffs);
         $data['updated_by'] = User::getFullName(Auth::getUserID());
@@ -853,6 +861,31 @@ class Notification
         }
     }
 
+    /**
+     * Method used to get list of addresses that were email sent to.
+     *
+     * @access  public
+     * @param   integer $issue_id The issue ID
+     * @return  array   list of addresse
+     */
+    function getLastNotifiedAddresses($issue_id = null)
+    {
+        global $_EVENTUM_LAST_NOTIFIED_LIST;
+
+        if (is_null($_EVENTUM_LAST_NOTIFIED_LIST)) {
+            return null;
+        }
+
+        if (is_null($issue_id)) {
+            // return all addresses in flat view
+            $ret = array_values($_EVENTUM_LAST_NOTIFIED_LIST);
+        } else {
+            // return address list for specific issue_id only.
+            $ret = $_EVENTUM_LAST_NOTIFIED_LIST[$issue_id];
+        }
+        return array_unique($ret);
+    }
+
 
     /**
      * Method used to format and send the email notifications.
@@ -869,6 +902,8 @@ class Notification
      */
     function notifySubscribers($issue_id, $emails, $type, $data, $subject, $internal_only, $type_id = false, $headers = false)
     {
+        global $_EVENTUM_LAST_NOTIFIED_LIST;
+
         // open text template
         $tpl = new Template_API;
         $tpl->setTemplate('notifications/' . $type . '.tpl.text');
@@ -961,6 +996,8 @@ class Notification
                 $full_subject = "[#$issue_id] $subject: $extra_subject";
             }
             $mail->send($from, $emails[$i], $full_subject, TRUE, $issue_id, $final_type, $sender_usr_id, $type_id);
+
+            $_EVENTUM_LAST_NOTIFIED_LIST[$issue_id][] = $emails[$i];
         }
 
         // restore correct language
@@ -1109,7 +1146,7 @@ class Notification
             }
             $recipient_usr_id = User::getUserIDByEmail(Mail_API::getEmailAddress($recipient));
 
-            if (!Workflow::shouldEmailAddress($prj_id, Mail_API::getEmailAddress($recipient))) {
+            if (!Workflow::shouldEmailAddress($prj_id, Mail_API::getEmailAddress($recipient), $issue_id, 'auto_created')) {
                 return;
             }
             $data = Issue::getDetails($issue_id);
@@ -1519,7 +1556,7 @@ class Notification
         $emails = array();
         for ($i = 0; $i < count($users); $i++) {
             $prefs = Prefs::get($users[$i]);
-            if ((!empty($prefs)) && (@$prefs["receive_assigned_emails"][$prj_id])) {
+            if ((!empty($prefs)) && (@$prefs["receive_assigned_emails"][$prj_id]) && ($users[$i] != Auth::getUserID())) {
                 $emails[] = User::getFromHeader($users[$i]);
             }
         }
