@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -26,7 +26,7 @@
 // +----------------------------------------------------------------------+
 //
 
-include_once(APP_INC_PATH . "workflow/class.abstract_workflow_backend.php");
+require_once(APP_INC_PATH . "workflow/class.abstract_workflow_backend.php");
 
 /**
  * Example workflow backend class. For example purposes it will print what
@@ -43,7 +43,7 @@ class Example_Workflow_Backend extends Abstract_Workflow_Backend
      * @param integer $issue_id The ID of the issue.
      * @param integer $usr_id The ID of the user.
      * @param array $old_details The old details of the issues.
-     * @param array $changes The changes that were applied to this issue (the $HTTP_POST_VARS)
+     * @param array $changes The changes that were applied to this issue (the $_POST)
      */
     function handleIssueUpdated($prj_id, $issue_id, $usr_id, $old_details, $changes)
     {
@@ -84,7 +84,7 @@ class Example_Workflow_Backend extends Abstract_Workflow_Backend
      * @param   integer $issue_id The ID of the issue.
      * @param   integer $usr_id The id of the user who locked the issue.
      * @param   array $old_details The old details of the issue.
-     * @param   array $changes The changes that were applied to this issue (the $HTTP_POST_VARS)
+     * @param   array $changes The changes that were applied to this issue (the $_POST)
      */
     function handlePriorityChange($prj_id, $issue_id, $usr_id, $old_details, $changes)
     {
@@ -113,8 +113,9 @@ class Example_Workflow_Backend extends Abstract_Workflow_Backend
      * @param   integer $issue_id The ID of the issue.
      * @param   integer $usr_id The user ID of the person posting this new note
      * @param   boolean $closing If the issue is being closed
+     * @param   integer $note_id The ID of the new note
      */
-    function handleNewNote($prj_id, $issue_id, $usr_id, $closing)
+    function handleNewNote($prj_id, $issue_id, $usr_id, $closing, $note_id)
     {
         echo "Workflow: New Note<br />\n";
     }
@@ -296,4 +297,3 @@ class Example_Workflow_Backend extends Abstract_Workflow_Backend
         }
     }
 }
-?>
\ No newline at end of file
