@@ -41,7 +41,7 @@ ini_set('memory_limit', '128M');
 ini_set('session.cache_limiter', 'nocache');
 
 define('APP_URL', 'http://www.mysql.com/products/eventum/');
-define('APP_VERSION', '2.0.1');
+define('APP_VERSION', '2.1');
 
 // define base path
 define('APP_PATH', realpath(dirname(__FILE__)) . '/');
@@ -150,6 +150,8 @@ if (!defined('APP_EMAIL_ENCODING')) {
     }
 }
 
+define('APP_HIDE_CLOSED_STATS_COOKIE', 'eventum_hide_closed_stats');
+
 if (APP_BENCHMARK) {
     // always benchmark the scripts
     require_once 'Benchmark/Timer.php';
@@ -157,20 +159,6 @@ if (APP_BENCHMARK) {
     $bench->start();
 }
 
-// handle the language preferences now
-$avail_langs = array(
-    'pl_PL' =>  'Polish',
-    'en_US' =>  'English',
-#    'ru_RU' =>  'Russian',
-#    'de_DE' =>  'German',
-#    'fr_FR' =>  'French',
-    'it_IT' =>  'Italian',
-    'fi_FI' =>  'Finnish',
-#    'es_ES' =>  'Spanish',
-#    'nl_NL' =>  'Dutch',
-    'sv_SE' =>  'Swedish',
-);
-
 include_once(APP_INC_PATH . 'class.language.php');
 include_once(APP_INC_PATH . 'db_access.php');
 include_once(APP_INC_PATH . 'class.auth.php');
