@@ -4,7 +4,7 @@
 require_once(dirname(__FILE__) . "/../../../init.php");
 
 // make backup copy
-$backup_file = APP_PATH . "config.inc.pre_1_7_0.php";
+$backup_file = APP_PATH . "config.inc.pre_1_5_3.php";
 if (copy(APP_PATH . "config.inc.php", $backup_file) == false) {
     echo "Unable to create backup copy of config.inc.php. Please check your base directory is writeable and try again.";
     exit(1);
@@ -20,13 +20,7 @@ $config_contents = str_replace("%{APP_SQL_DBPASS}%", APP_SQL_DBPASS, $config_con
 $config_contents = str_replace("%{APP_TABLE_PREFIX}%", APP_TABLE_PREFIX, $config_contents);
 $config_contents = str_replace("%{APP_HOSTNAME}%", APP_HOSTNAME, $config_contents);
 $config_contents = str_replace("%{APP_RELATIVE_URL}%", APP_RELATIVE_URL, $config_contents);
-if (APP_ENABLE_FULLTEXT == true) {
-    $fulltext = 'true';
-} else {
-    $fulltext = 'false';
-}
-$config_contents = str_replace("'%{APP_ENABLE_FULLTEXT}%'", $fulltext, $config_contents);
-$config_contents = str_replace("%{APP_VERSION}%", "1.7.0", $config_contents);
+$config_contents = str_replace("%{APP_VERSION}%", "1.5.3", $config_contents);
 if (stristr(APP_BASE_URL, 'https://') !== false) {
     $protocol_type = 'https://';
 } else {
@@ -46,5 +40,5 @@ if ($fp === FALSE) {
 }
 fclose($fp);
 ?>
-Done. Your configuration file (config.inc.php) has been upgraded to version 1.7.0.<br />
+Done. Your configuration file (config.inc.php) has been upgraded to version 1.5.3.<br />
 A backup copy has been made in the file <i>'<?php echo $backup_file; ?>'</i>.
\ No newline at end of file
